@@ -10,8 +10,8 @@ def onSynchronizeStateChange(state, event):
     response.write('<input style="display: none;" name="contentSyncStep" value="%s">' % state.step)   
     response.write('<input style="display: none;" name="contentSyncTotal" value="%s">' % state.total)
     response.write('<input style="display: none;" name="contentSyncProgress" value="%s">' % state.index)
-    if state.target is not None:
-        response.write('<input style="display: none;" name="contentSyncLabel" value="%s">' % state.target.title_or_id())        
+    if state.label is not None:
+        response.write('<input style="display: none;" name="contentSyncLabel" value="%s">' % state.label)        
     if state.message:
         response.write('<input style="display: none;" name="contentSyncLog" value="%s">' % state.message) 
 
